Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(25)

Unified Diff: chrome/android/javatests/src/org/chromium/chrome/browser/notifications/NotificationPlatformBridgeIntentTest.java

Issue 1919183003: Rename NotificationUIManager to NotificationPlatformBridge (1/2) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/javatests/src/org/chromium/chrome/browser/notifications/NotificationPlatformBridgeIntentTest.java
diff --git a/chrome/android/javatests/src/org/chromium/chrome/browser/notifications/NotificationUIManagerIntentTest.java b/chrome/android/javatests/src/org/chromium/chrome/browser/notifications/NotificationPlatformBridgeIntentTest.java
similarity index 92%
rename from chrome/android/javatests/src/org/chromium/chrome/browser/notifications/NotificationUIManagerIntentTest.java
rename to chrome/android/javatests/src/org/chromium/chrome/browser/notifications/NotificationPlatformBridgeIntentTest.java
index 17d73b78ec58c6e61665be6dbc88f674151cee78..68ebebc245cc594f79453f88ed5f81cf4ebf74b1 100644
--- a/chrome/android/javatests/src/org/chromium/chrome/browser/notifications/NotificationUIManagerIntentTest.java
+++ b/chrome/android/javatests/src/org/chromium/chrome/browser/notifications/NotificationPlatformBridgeIntentTest.java
@@ -23,13 +23,14 @@ import org.chromium.content.browser.test.util.Criteria;
import org.chromium.content.browser.test.util.CriteriaHelper;
/**
* Instrumentation tests for the Notification UI Manager implementation on Android.
*
* Exercises the handling of intents and explicitly does not do anything in startMainActivity so
* that the responsibility for correct initialization, e.g. loading the native library, lies with
* the code exercised by this test.
*/
-public class NotificationUIManagerIntentTest extends ChromeActivityTestCaseBase<ChromeActivity> {
+public class NotificationPlatformBridgeIntentTest
+ extends ChromeActivityTestCaseBase<ChromeActivity> {
/**
* Name of the Intent extra holding the notification id. This is set by the framework when a
* notification preferences intent has been triggered from there, which could be one of the
@@ -37,7 +38,7 @@ public class NotificationUIManagerIntentTest extends ChromeActivityTestCaseBase<
*/
public static final String EXTRA_NOTIFICATION_ID = "notification_id";
- public NotificationUIManagerIntentTest() {
+ public NotificationPlatformBridgeIntentTest() {
super(ChromeActivity.class);
}
@@ -97,9 +98,9 @@ public class NotificationUIManagerIntentTest extends ChromeActivityTestCaseBase<
.addCategory(Notification.INTENT_CATEGORY_NOTIFICATION_PREFERENCES)
.setClassName(context, ChromeLauncherActivity.class.getName())
.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
- .putExtra(EXTRA_NOTIFICATION_ID, NotificationUIManager.PLATFORM_ID)
+ .putExtra(EXTRA_NOTIFICATION_ID, NotificationPlatformBridge.PLATFORM_ID)
.putExtra(NotificationConstants.EXTRA_NOTIFICATION_TAG,
- NotificationUIManager.makePlatformTag(
+ NotificationPlatformBridge.makePlatformTag(
42L /* persistentNotificationId */, "https://example.com",
null /* tag */));
@@ -120,7 +121,7 @@ public class NotificationUIManagerIntentTest extends ChromeActivityTestCaseBase<
/**
* Tests the browser initialization code when a notification has been activated. This will be
* routed through the NotificationService which starts the browser process, which in turn will
* create an instance of the NotificationUIManager.
*
* The created intent does not carry significant data and is expected to fail, but has to be
* sufficient for the Java code to trigger start-up of the browser process.
@@ -129,7 +130,7 @@ public class NotificationUIManagerIntentTest extends ChromeActivityTestCaseBase<
@Feature({"Browser", "Notifications"})
public void testLaunchProcessForNotificationActivation() throws Exception {
assertFalse("The native library should not be loaded yet", LibraryLoader.isInitialized());
- assertNull(NotificationUIManager.getInstanceForTests());
+ assertNull(NotificationPlatformBridge.getInstanceForTests());
Context context = getInstrumentation().getTargetContext().getApplicationContext();
@@ -152,11 +153,11 @@ public class NotificationUIManagerIntentTest extends ChromeActivityTestCaseBase<
CriteriaHelper.pollUiThread(new Criteria("Browser process was never started.") {
@Override
public boolean isSatisfied() {
- return NotificationUIManager.getInstanceForTests() != null;
+ return NotificationPlatformBridge.getInstanceForTests() != null;
}
});
assertTrue("The native library should be loaded now", LibraryLoader.isInitialized());
- assertNotNull(NotificationUIManager.getInstanceForTests());
+ assertNotNull(NotificationPlatformBridge.getInstanceForTests());
}
}
@@ -23,13 +23,14 @@ import org.chromium.content.browser.test.util.Criteria;
import org.chromium.content.browser.test.util.CriteriaHelper;
/**
- * Instrumentation tests for the Notification UI Manager implementation on Android.
+ * Instrumentation tests for the Notification Platform Bridge.
*
* Exercises the handling of intents and explicitly does not do anything in startMainActivity so
@@ -120,7 +121,7 @@ public class NotificationUIManagerIntentTest extends ChromeActivityTestCaseBase<
* Tests the browser initialization code when a notification has been activated. This will be
* routed through the NotificationService which starts the browser process, which in turn will
- * create an instance of the NotificationUIManager.
+ * create an instance of the NotificationPlatformBridge.
*
* The created intent does not carry significant data and is expected to fail, but has to be

Powered by Google App Engine
This is Rietveld 408576698